#
# spec file for package pinentry
#
# Copyright (c) 2013 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           pinentry
Version:        0.8.3
Release:        4.5
Summary:        Collection of Simple PIN or Passphrase Entry Dialogs
License:        GPL-2.0+
Group:          Productivity/Other
Url:            http://www.gnupg.org/aegypten/
Source:         ftp://ftp.gnupg.org/gcrypt/pinentry/%{name}-%{version}.tar.bz2
Source1:        ftp://ftp.gnupg.org/gcrypt/pinentry/%{name}-%{version}.tar.bz2.sig
Source2:        pinentry.keyring
Source3:        pinentry
Patch0:         moreSecureMemoryForPinentry-qt.diff
Patch1:         pinentry-0.7.2-gtk+-2.4.diff
Patch2:         pinentry-0.7.2-bnc179996_disable_inputmethod_for_passords.patch
# PATCH-FIX-UPSTREAM allow paste for pinentry-qt4 (bnc#690514)
Patch4:         pinentry-0.8.1-allow_paste_qt4.patch
# PATCH-FIX-UPSTREAM allow paste for pinentry-gtk-2 (bnc#690514)
Patch5:         pinentry-0.8.1-allow_paste_gtk2.patch
# PATCH-FIX-SUSE fix qt4 password entry not to allow IM (bnc#725471)
Patch6:         qt4-disable-inputmethod-for-passwords.diff
# PATCH-FIX-SUSE add -ltinfo to fix build
Patch8:         pinentry-0.8.1-tinfo.patch
BuildRequires:  automake >= 1.10
BuildRequires:  cmake
BuildRequires:  libcap-devel
BuildRequires:  libdrm-devel
BuildRequires:  libjpeg-devel
BuildRequires:  libqt4-devel
BuildRequires:  ncurses-devel
BuildRequires:  update-desktop-files
BuildRequires:  pkgconfig(gtk+-2.0)
%if %suse_version >= 1230
BuildRequires:  gpg-offline
%endif
PreReq:         %install_info_prereq
Provides:       pinentry-dialog
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
%global         ncursesw_config %(set -- %{_bindir}/ncursesw*-config; echo ${1})

%description
This is a collection of simple PIN or passphrase entry dialogs which
utilize the Assuan protocol as described by the Aegypten project.

%package -n pinentry-qt4
Version:        %{version}
Release:        4.5
Summary:        Collection of Simple PIN or Passphrase Entry Dialogs
Group:          Productivity/Other
Requires:       pinentry
Provides:       pinentry-dialog
Provides:       pinentry-gui
Provides:       pinentry-qt = %{version}
Provides:       pinentry:/usr/bin/pinentry-qt4
Obsoletes:      pinentry-qt <= 0.8.3

%description -n pinentry-qt4
This is a collection of simple PIN or passphrase entry dialogs which
utilize the Assuan protocol as described by the Aegypten project.

%package -n pinentry-gtk2
Version:        %{version}
Release:        4.5
Summary:        Collection of Simple PIN or Passphrase Entry Dialogs
Group:          Productivity/Other
Requires:       pinentry
Provides:       pinentry-dialog
Provides:       pinentry-gui
Provides:       pinentry:/usr/bin/pinentry-gtk-2

%description -n pinentry-gtk2
This is a collection of simple PIN or passphrase entry dialogs which
utilize the Assuan protocol as described by the Aegypten project.

%prep
%{?gpg_verify: %gpg_verify %{S:1}}
%setup -q
%patch0 -p 1
%patch1 -p 1
%patch2 -p 1
%patch4 -p1
%patch5 -p1
%patch6 -p1
%patch8 -p1

%build
cp /usr/share/gettext/config.rpath .
autoreconf -fi
# Regenerate moc's
moc qt4/pinentrydialog.h > qt4/pinentrydialog.moc
moc qt4/qsecurelineedit.h > qt4/qsecurelineedit.moc
export CFLAGS="%{optflags} $(%{ncursesw_config} --cflags)"
export CXXFLAGS="%{optflags} $(%{ncursesw_config} --cflags)"
%configure \
	--enable-pinentry-curses \
	--enable-pinentry-qt4 \
	--enable-pinentry-gtk2 \
	--with-qt-dir=%{_libdir}/qt3/ \
	--with-qt-includes=%{_libdir}/qt3/include/ \
	--with-qt-libraries=%{_libdir}/qt3/%{_lib}/ \
	--without-ncurses-include-dir
make %{?_smp_mflags}

%install
%makeinstall DESTDIR=%{buildroot}

# remove symlink
rm -rf %{buildroot}%{_bindir}/pinentry
cp %{SOURCE3} %{buildroot}%{_bindir}

%post
%install_info --info-dir=.%{_infodir} .%{_infodir}/pinentry.info.gz

%postun
%install_info_delete --info-dir=.%{_infodir} .%{_infodir}/pinentry.info.gz

%files
%defattr(-,root,root)
%doc AUTHORS COPYING ChangeLog NEWS README
%doc %{_infodir}/pinentry*
%attr(755,root,root) %{_bindir}/pinentry
%attr(755,root,root) %{_bindir}/pinentry-curses

%files -n pinentry-qt4
%attr(755,root,root) %{_bindir}/pinentry-qt4

%files -n pinentry-gtk2
%attr(755,root,root) %{_bindir}/pinentry-gtk-2

%changelog
* Sat Dec 21 2013 coolo@suse.com
- disable qt3 support to avoid maintaining qt3 forever
* Mon Aug 19 2013 andreas.stieger@gmx.de
- update to 0.8.3
  * Add SETTIMEOUT command for the gtk+-2 pinentry.
- includes changes from 0.8.2:
  * New SETTIMEOUT command for the qt4 pinentry.
  * Wide character support for the curses pinentry.
    ( already present in openSUSE patched version)
  * Various bug fixes.
- drop pinentry-0.7.2-curses-utf-8.diff, implemented upstream
- drop pinentry-0.8.1-editing-cancelled_warning.patch, same
- refresh qt4-disable-inputmethod-for-passwords.diff
* Mon Apr 22 2013 meissner@suse.com
- %%makeinstall instead of %%make install.
* Mon Apr 15 2013 idonmez@suse.com
- Add Source URL, see https://en.opensuse.org/SourceUrls
- Add GPG checking
* Mon Dec  5 2011 vcizek@suse.com
- fixed licence of the pinentry-qt subpackage (bnc#734792)
* Wed Nov 30 2011 coolo@suse.com
- add automake as buildrequire to avoid implicit dependency
* Tue Nov 22 2011 vcizek@suse.com
- patch that fixes Glib warning (bnc#730453)
- add -ltinfo to fix build
* Fri Oct 21 2011 tiwai@suse.de
- fix pinentry-qt4 not to allow triggering IM (bnc#725471)
* Wed Sep 14 2011 vcizek@suse.com
- enable paste for pinentry-gtk2 (bnc#690514)
* Tue Sep 13 2011 vcizek@suse.com
- enable paste for pinentry-qt4 (bnc#690514)
* Thu Mar 24 2011 puzel@novell.com
- update to pinentry-0.8.1
  * The GTK pinentry now always sticks to the top and properly grabs
  the keyboard.
  * The protocol options default-cancel and default-ok now work for
  the pinentry-gtk2 and pinentry-qt (that is QT3).
- drop pinentry-qt-fix-1162.diff (in upstream)
- use spec-cleaner
* Tue Oct  5 2010 cristian.rodriguez@opensuse.org
- Add missing buildrequires on libcap-devel
* Mon Aug 23 2010 puzel@novell.com
- pinentry-qt-fix-1162.diff: fix active window issue (bnc#629502)
  Upstream Patch: https://bugs.g10code.com/gnupg/issue1162
* Wed Jul  7 2010 puzel@novell.com
- change pinentry script to not to rely on curses fallback
  mechanism if DISPLAY is not set
* Wed Mar 17 2010 puzel@novell.com
- update to pinentry-0.8.0
  * Beautified the qt4 pinentry
  * Minor enhancements.
* Sat Dec 19 2009 jengelh@medozas.de
- enable parallel build
* Wed Oct  7 2009 puzel@novell.com
- do not fail when no graphical pinentry is installed -
  try pinentry-curses instead (bnc#544365)
* Fri Aug 21 2009 puzel@novell.com
- all graphical pinentry (-qt,qt4,-gtk2) now provide pinentry-gui
* Tue Jun 30 2009 puzel@novell.com
- improve pinentry script: prefer pinentry-qt in KDE3 environment
  (bnc#514688)
* Wed Jun 24 2009 puzel@novell.com
- update to pinentry-0.7.6
  * Make Gtk+-2 pinentry transient to the root window.
  * Add Qt4 pinentry.
  * Fix utf-8 problem in Qt pinentries.
  * Return GPG_ERR_CANCELED if during a "CONFIRM" command the user
    closed the window.
  * Add quality bar.
- drop pinentry-gsize.patch (fixed in upstream)
- drop wrong-apostrophe.patch (fixed in upstream)
- drop pinentry-qt4.patch (native qt4 support added)
- simplify build section with configure macro and autoreconf
* Thu May 28 2009 puzel@suse.cz
- pinentry-qt4 (bnc#505134)
  - add pinentry-qt4.patch.bz2
* Mon Nov 10 2008 coolo@suse.de
- revert the last entry (reopened the bug)
* Wed Nov  5 2008 puzel@suse.cz
- pinentry requires pinentry-dialog (bnc#441084)
* Wed Jul 23 2008 puzel@suse.cz
- added pinentry-0.7.5-wrong-apostrophe.patch
  * fixes (bnc#411312)
* Mon Jun 16 2008 puzel@suse.cz
- removed pinentry-0.7.2-qt-utf8.diff workaround patch
  (not needed since [bnc#305725] is fixed)
* Wed Apr 16 2008 pcerny@suse.cz
- update to 0.7.5
  (small fixes, see package's changelog for details)
* Thu Apr 10 2008 werner@suse.de
- Use correct ncurses header for libncursesw
- Handle info file
- Use RPM_OPT_FLAGS even for c++ files
* Sun Mar 30 2008 ro@suse.de
- fix build with changed definition of g_malloc (gulong->gsize)
* Tue Sep 11 2007 ltinkl@suse.cz
- fix various utf-8 problems (#305725)
* Thu Mar 29 2007 ro@suse.de
- added ncurses-devel to buildreq
* Fri Jan  5 2007 anicka@suse.cz
- fix KDE detection in pinentry wrapper script
  (thanks llunak for a patch)
* Wed Nov 22 2006 anicka@suse.cz
- fixed Provides [#223074]
* Tue Nov 21 2006 nadvornik@suse.cz
- fixed pinentry script: dont use pinentry-curses in GUI [#205688]
- removed useless provides
* Mon Nov  6 2006 anicka@suse.de
- split graphical frontends (#217373)
- rewrite pinentry wrapper to use the right binary
* Mon Nov  6 2006 pnemec@suse.cz
- Fixed pinnentry wrapper #218257
* Sun Oct 15 2006 schwab@suse.de
- Make sure config.rpath is present.
* Tue Oct  3 2006 pnemec@suse.cz
- removed static simlink to pinentry-qt
- add script which use pinentry-qt only when KDE is detected
* Mon Jun 26 2006 mfabian@suse.de
- Bugzilla #179996: enable input methods in SecQlineEdit widgets
  only when "mode == Normal" (i.e. not when "mode == NoEcho" or
  "mode == Password"). Using input methods while inputting
  passwords is useless. See also Bugzilla #117115.
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Mon Dec 19 2005 ro@suse.de
- added symlink to filelist
* Fri Jul 29 2005 anicka@suse.cz
- update to 0.7.2
- remove part of gtk2 patch contained in new version
* Tue Nov  2 2004 postadal@suse.cz
- added patch gtk+-2.4.diff.bz2 for gtk2 support (removing gtk1 dependency)
* Tue Jul 13 2004 adrian@suse.de
- update to version 0.7.1
* Sat Jan 10 2004 adrian@suse.de
- build as user
* Tue Nov 18 2003 mc@suse.de
- increase secmem allocation for pinentry-qt to avoid
  "Out of memory" errors.
  (pinentry-0.6.9.moreSecureMemoryForPinentry-qt.diff)
* Mon Jun  2 2003 mc@suse.de
- remove pinentry-0.6.8-prevent-assuan-stderr.dif; no longer needed
- switch to version 0.6.9
  * a memory-issue present in 0.6.8
  * a minor build problem (make distclean now cleans up .moc files)
  * assuan protocol debug messages are not written to stderr
- fixed build on x86_64
* Tue Apr  8 2003 mc@suse.de
- prevent pinentry-qt to print the assuan protocol to stderr
* Fri Feb 21 2003 ro@suse.de
- fixed neededforbuild
* Tue Feb 11 2003 mc@suse.de
- initial release
